import datetime
from pydantic import BaseModel, StrictInt, StrictBool, StrictStr, validator
from typing import Union, Optional, List, Literal
from ergondata_executions.interfaces import APIBaseResponse


class IProcess(BaseModel):
    id: StrictStr
    name: StrictStr
    created_at: datetime.datetime
    updated_at: datetime.datetime


class IProcesses(BaseModel):
    processes: List[IProcess] = []


class GetProcessesErrorResponsePayload(BaseModel):
    error: StrictStr


class GetProcessesResponsePayload(APIBaseResponse):
    data: Optional[IProcesses]


class GetProcessesRequestPayload(BaseModel):
    database_id: StrictStr


class CreateProcessRequestPayload(BaseModel):
    process_title: StrictStr
    process_description: StrictStr
    database_id: StrictStr


class CreateProcessResponsePayload(APIBaseResponse):
    process_id: Optional[StrictStr] = None


class UpdateProcessRequestPayload(BaseModel):
    process_id: StrictStr
    process_name: StrictStr


class DeleteProcessRequestPayload(BaseModel):
    process_id: StrictStr


class CreateProcessMemberRequestPayload(BaseModel):
    process_id: StrictStr
    process_member_email: StrictStr
    process_member_username: Optional[StrictStr]
    process_member_password: Optional[StrictStr]

    @validator("process_member_username", pre=True, always=True, allow_reuse=True)
    def validate_username_field(cls, value, values):
        if values.get("process_member_password"):
            if not value:
                raise ValueError(
                    "If you want to create a new user as a db member please send username and password keys."
                )
        return value

    @validator("process_member_password", pre=True, always=True)
    def validate_password_field(cls, value, values):
        if values.get("process_member_username"):
            if not value:
                raise ValueError(
                    "If you want to create a new user as a db member please send username and password keys."
                )
        return value


class CreateProcessMemberResponsePayload(APIBaseResponse):
    process_member_id: Optional[StrictStr] = None


class GetProcessMembersRequestPayload(BaseModel):
    process_id: StrictStr


class IUser(BaseModel):
    id: StrictStr
    username: StrictStr
    email: Optional[StrictStr]


class IProcessMember(BaseModel):
    id: StrictStr
    email: StrictStr
    created_at: datetime.datetime
    updated_at: datetime.datetime


class IProcessMembers(BaseModel):
    process_members: List[IProcessMember] = []


class GetProcessMembersResponsePayload(APIBaseResponse):
    data: Optional[IProcessMembers] = None


class DeleteProcessMemberRequestPayload(BaseModel):
    process_member_id: StrictStr


class AddProcessMemberPermissionsRequestPayload(BaseModel):
    process_member_id: StrictStr
    process_member_permissions: List[StrictStr]


class DeleteProcessMemberPermissionsRequestPayload(BaseModel):
    process_member_id: StrictStr
    process_member_permission_id: StrictStr


class IUserPermission(BaseModel):
    id: StrictStr
    name: StrictStr
    type: Literal["db_member", "client_owner", "process_member"]
    created_at: datetime.datetime
    updated_at: datetime.datetime


class IUserPermissions(BaseModel):
    user_permissions: List[IUserPermission] = []


class GetProcessMemberPermissionsResponsePayload(APIBaseResponse):
    data: IUserPermissions


class GetProcessMemberPermissionsRequestPayload(BaseModel):
    process_member_id: StrictStr




import requests
from ergondata_executions.controllers.process.interfaces import *
from ergondata_executions.controllers.auth.controller import AuthController


class ProcessMemberController:

    CREATE_PROCESS_MEMBER_URL = "create/database/process/member"
    GET_PROCESS_MEMBERS_URL = "get/database/process/{0}/members"
    DELETE_PROCESS_MEMBER_URL = "delete/database/process/member/{0}"
    ADD_PROCESS_MEMBER_PERMISSIONS_URL = "create/database/process/member/permissions"
    DELETE_PROCESS_MEMBER_PERMISSIONS_URL = "delete/database/process/member/{0}/permission/{1}"
    GET_PROCESS_MEMBER_PERMISSIONS_URL = ""

    def __init__(self, api_client: AuthController):
        self.api_client = api_client

    def create_process_member(self, params: CreateProcessMemberRequestPayload) -> CreateProcessMemberResponsePayload:

        self.api_client.log_info(f"Adding Process member to process {params.process_id}.")

        try:

            res = requests.post(
                url=f"{self.api_client.ROOT_URL}{self.CREATE_PROCESS_MEMBER_URL}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = CreateProcessMemberResponsePayload(**res.json())
            
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to add process member {e}.")

            response_payload = CreateProcessMemberResponsePayload(
                status="error",
                message=str(e)
            )

            return response_payload

    def get_process_members(self, params: GetProcessMembersRequestPayload) -> GetProcessMembersResponsePayload:

        self.api_client.log_info(f"Getting process members for Process {params.process_id}.")

        try:

            res = requests.get(
                url=f"{self.api_client.ROOT_URL}{self.GET_PROCESS_MEMBERS_URL.format(params.process_id)}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = GetProcessMembersResponsePayload(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to get process members {e}.")
            response_payload = GetProcessMembersResponsePayload(
                status="error",
                message=str(e)
            )

            return response_payload

    def delete_process_member(self, params: DeleteProcessMemberRequestPayload) -> APIBaseResponse:

        self.api_client.log_info(f"Deleting Process member id {params.process_member_id}.")

        try:

            res = requests.delete(
                url=f"{self.api_client.ROOT_URL}{self.DELETE_PROCESS_MEMBER_URL.format(params.process_member_id)}",
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to delete process member {e}.")

            response_payload = APIBaseResponse(
                status="error",
                message=str(e)
            )

            return response_payload

    def add_process_member_permissions(self, params: AddProcessMemberPermissionsRequestPayload) -> APIBaseResponse:

        self.api_client.log_info(f"Adding process member id {params.process_member_id} permissions {params.process_member_permissions}.")

        try:

            res = requests.post(
                url=f"{self.api_client.ROOT_URL}{ProcessMemberController.ADD_PROCESS_MEMBER_PERMISSIONS_URL}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to add Process member permissions {e}.")

            response_payload = APIBaseResponse(
                status="error",
                message=str(e)
            )

            return response_payload

    def remove_process_member_permissions(self, params: DeleteProcessMemberPermissionsRequestPayload) -> APIBaseResponse:

        self.api_client.log_info(f"Deleting Process member id {params.process_member_id} permission {params.process_member_permission_id}.")

        try:

            res = requests.delete(
                url=f"{self.api_client.ROOT_URL}{self.DELETE_PROCESS_MEMBER_PERMISSIONS_URL.format(params.process_member_id, params.process_member_permission_id)}",
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to delete Process member permissions {e}.")

            response_payload = APIBaseResponse(
                status="error",
                message=str(e)
            )

            return response_payload

    def get_process_member_permissions(self, params: GetProcessMemberPermissionsRequestPayload) -> GetProcessMemberPermissionsResponsePayload:

        self.api_client.log_info(f"Getting Process member {params.process_member_id} permissions.")

        try:

            res = requests.get(
                url=f"{self.api_client.ROOT_URL}{self.GET_PROCESS_MEMBER_PERMISSIONS_URL.format(params.process_member_id)}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = GetProcessMemberPermissionsResponsePayload(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to delete get Process member permissions {e}.")

            response_payload = GetProcessMemberPermissionsResponsePayload(
                status="error",
                message=str(e)
            )

            return response_payload


class ProcessController(ProcessMemberController):

    GET_PROCESSES_URL = "get/database/{0}/processes"
    CREATE_PROCESS_URL = "create/database/process"
    UPDATE_PROCESS_URL = "update/database/process"
    DELETE_PROCESS_URL = "delete/database/process/{0}"

    def __init__(self, api_client: AuthController):
        self.api_client = api_client
        super(ProcessController, self).__init__(api_client=api_client)

    def get_processes(self, params: GetProcessesRequestPayload) -> GetProcessesResponsePayload:

        self.api_client.log_info(f"Getting Processes for database id {params.database_id}.")

        try:

            res = requests.get(
                url=f"{self.api_client.ROOT_URL}{ProcessController.GET_PROCESSES_URL.format(params.database_id)}",
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = GetProcessesResponsePayload(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to get Processes {e}.")

            response_payload = GetProcessesResponsePayload(
                status="error",
                message=str(e)
            )
            return response_payload

    def create_process(self, params: CreateProcessRequestPayload) -> CreateProcessResponsePayload:

        self.api_client.log_info(f"Creating Process {params.process_title}.")

        try:

            res = requests.post(
                url=f"{self.api_client.ROOT_URL}{self.CREATE_PROCESS_URL}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = CreateProcessResponsePayload(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to create Process {e}.")

            response_payload = CreateProcessResponsePayload(
                status="error",
                message=str(e)
            )
            return response_payload

    def update_process(self, params: UpdateProcessRequestPayload) -> APIBaseResponse:

        self.api_client.log_info(f"Updating Process {params.process_id}.")

        try:

            res = requests.put(
                url=f"{self.api_client.ROOT_URL}{self.UPDATE_PROCESS_URL}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to update Process {e}.")

            response_payload = CreateProcessResponsePayload(
                status="error",
                message=str(e)
            )
            return response_payload

    def delete_process(self, params: DeleteProcessRequestPayload) -> APIBaseResponse:

        self.api_client.log_info(f"Deleting Process {params.process_id}.")

        try:

            res = requests.delete(
                url=f"{self.api_client.ROOT_URL}{self.DELETE_PROCESS_URL.format(params.process_id)}",
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to delete Process {e}.")

            response_payload = CreateProcessResponsePayload(
                status="error",
                message=str(e)
            )
            return response_payload





import requests
from ergondata_executions.controllers.auth.interfaces import *
from ergondata_executions.api_logger import APILogger


class AuthController(APILogger):

    ROOT_URL = "https://executions.ergondata.com.br/api/"
    # ROOT_URL = "http://127.0.0.1:8000/api/"
    AUTH_URL = "auth"

    def __init__(self, auth: AuthRequestPayload, timeout: int = 10, enable_logs: bool = True):
        super(AuthController, self).__init__(enable_logs=enable_logs)
        self.auth = auth
        self.timeout = timeout
        self.auth_token = AuthController.__authenticate(self=self).token
        self.execution_token = None

    @property
    def auth_header(self):
        return {"Authorization": f"Bearer {self.auth_token}"}

    @property
    def exec_header(self):
        return {"Authorization": f"Bearer {self.execution_token}"}

    def __authenticate(self) -> AuthResponsePayload:

        try:

            self.log_info(f"Authenticating user { self.auth.username }")
            res = requests.post(
                url=f"{AuthController.ROOT_URL}{AuthController.AUTH_URL}",
                json=self.auth.model_dump(),
                timeout=self.timeout
            )
            response = AuthResponsePayload(**res.json())

            if res.status_code == 200:
                self.log_info(response)
            else:
                self.log_error(response.message)

            return response

        except BaseException as e:

            self.log_error(f"Failed to authenticate user. {e}")
            response = AuthResponsePayload(
                status="error",
                message=str(e)
            )
            return response





from pydantic import BaseModel, StrictStr
from typing import Union, Optional
from ergondata_executions.interfaces import APIBaseResponse


class AuthRequestPayload(BaseModel):
    username: StrictStr
    password: StrictStr
    client_id: StrictStr


class AuthSuccessResponsePayload(BaseModel):
    token: Optional[Union[StrictStr, None]]


class AuthResponsePayload(APIBaseResponse):
    token: Optional[StrictStr] = None




from pydantic import BaseModel, StrictStr, StrictBool
from typing import Union, Optional, Literal, List


class APIBaseResponse(BaseModel):
    status: Literal["success", "error"]
    message: StrictStr
    error_messages: Optional[List[object]] = None


class IEmailRecipient(BaseModel):
    email: StrictStr
    pre_header_name: StrictStr


class IEmailIntegrationData(BaseModel):
    active: StrictBool
    recipients: Union[List[IEmailRecipient], None] = None


class UpdateEmailRecipientsPayload(BaseModel):
    action: Literal["overwrite", "add", "remove"]
    emails: List[IEmailRecipient]



import requests
from ergondata_executions.controllers.database.interfaces import *
from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.process.controller import ProcessController


class DBMemberController(ProcessController):

    CREATE_DB_MEMBER_URL = "create/database/member"
    GET_DB_MEMBERS_URL = "get/database/{0}/members"
    DELETE_DB_MEMBER_URL = "delete/database/member/{0}"
    ADD_DB_MEMBER_PERMISSIONS_URL = "create/database/member/permissions"
    DELETE_DB_MEMBER_PERMISSIONS_URL = "delete/database/member/{0}/permission/{1}"
    GET_DB_MEMBER_PERMISSIONS_URL = "get/database/member/{0}/permissions"

    def __init__(self, api_client: AuthController):
        self.api_client = api_client
        super(DBMemberController, self).__init__(api_client=api_client)

    def create_database_member(
        self,
        params: CreateDatabaseMemberRequestPayload
    ) -> CreateDatabaseMemberResponsePayload:

        self.api_client.log_info(f"Adding database member to database {params.database_id}.")

        try:

            res = requests.post(
                url=f"{self.api_client.ROOT_URL}{self.CREATE_DB_MEMBER_URL}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = CreateDatabaseMemberResponsePayload(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)
                
            return response_payload

        except BaseException as e:
            self.api_client.log_error(f"Failed to create database member {e}")
            response_payload = CreateDatabaseMemberResponsePayload(
                status="error",
                message=str(e)
            )

            return response_payload

    def get_database_members(self, params: GetDatabaseMembersRequestPayload) -> GetDatabaseMembersResponsePayload:

        self.api_client.log_info(f"Getting database members for database {params.database_id}.")

        try:

            res = requests.get(
                url=f"{self.api_client.ROOT_URL}{self.GET_DB_MEMBERS_URL.format(params.database_id)}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = GetDatabaseMembersResponsePayload(**res.json())

            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload

        except BaseException as e:
            self.api_client.log_error(f"Failed to delete database {e}.")
            response_payload = GetDatabaseMembersResponsePayload(
                status="error",
                message=str(e)
            )

            return response_payload

    def delete_database_member(self, params: DeleteDatabaseMemberRequestPayload) -> APIBaseResponse:

        self.api_client.log_info(f"Deleting database member id {params.database_member_id}.")

        try:

            res = requests.delete(
                url=f"{self.api_client.ROOT_URL}{self.DELETE_DB_MEMBER_URL.format(params.database_member_id)}",
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to delete database member {e}.")
            response_payload = APIBaseResponse(
                status="error",
                message=str(e)
            )

            return response_payload

    def add_database_member_permissions(self, params: AddDatabaseMemberPermissionsRequestPayload) -> APIBaseResponse:

        self.api_client.log_info(
            f"Adding database member id {params.database_member_id} permissions {params.database_member_permissions}."
        )

        try:

            res = requests.post(
                url=f"{self.api_client.ROOT_URL}{DBMemberController.ADD_DB_MEMBER_PERMISSIONS_URL}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to add database member permissions {e}.")

            response_payload = APIBaseResponse(
                status="error",
                message=str(e)
            )

            return response_payload

    def remove_database_member_permissions(self, params: DeleteDatabaseMemberPermissionsRequestPayload) -> APIBaseResponse:

        """
            This method is used to delete database member permissions
        """


        self.api_client.log_info(f"Deleting database member id {params.database_member_id} permission {params.database_member_permission_id}.")

        try:

            res = requests.delete(
                url=f"{self.api_client.ROOT_URL}{self.DELETE_DB_MEMBER_PERMISSIONS_URL.format(params.database_member_id, params.database_member_permission_id)}",
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to delete database member permissions {e}.")

            response_payload = APIBaseResponse(
                status="error",
                message=str(e)
            )

            return response_payload

    def get_database_member_permissions(self, params: GetDatabaseMemberPermissionsRequestPayload) -> GetDatabaseMemberPermissionsResponsePayload:

        """
            This method is used to get a database member permissions
        """

        self.api_client.log_info(f"Getting database member {params.database_member_id} permissions.")

        try:

            res = requests.get(
                url=f"{self.api_client.ROOT_URL}{self.GET_DB_MEMBER_PERMISSIONS_URL.format(params.database_member_id)}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = GetDatabaseMemberPermissionsResponsePayload(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to delete get databases member permissions {e}.")

            response_payload = GetDatabaseMemberPermissionsResponsePayload(
                status="error",
                message=str(e)
            )

            return response_payload


class DBController(DBMemberController):

    GET_DBS_URL = "get/databases"
    CREATE_DB_URL = "create/database"
    UPDATE_DB_URL = "update/database"
    DELETE_DB_URL = "delete/database/{0}"

    def __init__(self, api_client: AuthController):
        self.api_client = api_client
        super(DBController, self).__init__(api_client=api_client)

    def get_databases(self) -> GetDatabasesResponsePayload:

        self.api_client.log_info("Getting databases.")

        try:

            res = requests.get(
                url=f"{self.api_client.ROOT_URL}{self.GET_DBS_URL}",
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = GetDatabasesResponsePayload(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to get databases {e}.")
            response_payload = GetDatabasesResponsePayload(
                status="error",
                message=str(e)
            )
            return response_payload

    def create_database(self, params: CreateDatabaseRequestPayload) -> CreateDatabaseResponsePayload:

        """
            This method is used to create a database
        """

        self.api_client.log_info(message=f"Creating database {params.database_name}.")

        try:

            res = requests.post(
                url=f"{self.api_client.ROOT_URL}{self.CREATE_DB_URL}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )
            response_payload = CreateDatabaseResponsePayload(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to create database {e}.")
            response_payload = CreateDatabaseResponsePayload(
                status="error",
                message=str(e)
            )
            return response_payload

    def update_database(self, params: UpdateDatabaseRequestPayload) -> APIBaseResponse:

        """
            This method is used to update a database name
        """

        self.api_client.log_info(f"Updating database {params.database_id}.")
        try:

            res = requests.put(
                url=f"{self.api_client.ROOT_URL}{self.UPDATE_DB_URL}",
                json=params.model_dump(),
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload

        except BaseException as e:

            self.api_client.log_error(f"Failed to update database {e}.")
            response_payload = APIBaseResponse(
                status="error",
                message=str(e)
            )
            return response_payload

    def delete_database(self, params: DeleteDatabaseRequestPayload) -> APIBaseResponse:


        self.api_client.log_info(f"Deleting database {params.database_id}.")

        try:

            res = requests.delete(
                url=f"{self.api_client.ROOT_URL}{self.DELETE_DB_URL.format(params.database_id)}",
                headers=self.api_client.auth_header,
                timeout=self.api_client.timeout
            )

            response_payload = APIBaseResponse(**res.json())
            response_payload = APIBaseResponse(**res.json())
            if res.status_code == 200:
                self.api_client.log_info(response_payload)
            else:
                self.api_client.log_error(response_payload)

            return response_payload
        except BaseException as e:

            self.api_client.log_error(f"Failed to delete database {e}.")

            response_payload = CreateDatabaseResponsePayload(
                status="error",
                message=str(e)
            )
            return response_payload





import logging
from typing import Literal


class APILogger:

    def __init__(self, enable_logs: bool = True):
        self.enable_logs = enable_logs
        logging.basicConfig(level=logging.INFO)
        self.logger = logging.getLogger()

    def log_error(self, message):
        if self.enable_logs:
            self.logger.error(message)

    def log_info(self, message):
        if self.enable_logs:
            self.logger.info(message)

    def log_warning(self, message):
        if self.enable_logs:
            self.logger.warning(message)



    def log(self, message, level: Literal["warning", "info", "debug", "error"] = "info"):

        if self.enable_logs:
            if level == "info":
                self.logger.info(message)
            if level == "warning":
                self.logger.warning(message)
            if level == "error":
                self.logger.error(message)



import datetime
from pydantic import BaseModel, StrictInt, StrictBool, StrictStr, validator
from typing import Union, Optional, List, Literal
from ergondata_executions.interfaces import APIBaseResponse


class IDatabase(BaseModel):
    id: StrictStr
    name: StrictStr
    created_at: datetime.datetime
    updated_at: datetime.datetime


class IDatabases(BaseModel):
    databases: List[IDatabase] = []


class GetDatabasesErrorResponsePayload(BaseModel):
    error: StrictStr


class GetDatabasesResponsePayload(APIBaseResponse):
    data: Optional[IDatabases]


class CreateDatabaseRequestPayload(BaseModel):
    database_name: StrictStr


class CreateDatabaseResponsePayload(APIBaseResponse):
    database_id: Optional[StrictStr] = None


class UpdateDatabaseRequestPayload(BaseModel):
    database_id: StrictStr
    database_name: StrictStr


class DeleteDatabaseRequestPayload(BaseModel):
    database_id: StrictStr


class CreateDatabaseMemberRequestPayload(BaseModel):
    database_id: StrictStr
    database_member_email: StrictStr
    database_member_username: Optional[StrictStr] = None


class CreateDatabaseMemberResponsePayload(APIBaseResponse):
    database_member_id: Optional[StrictStr] = None


class GetDatabaseMembersRequestPayload(BaseModel):
    database_id: StrictStr


class IUser(BaseModel):
    id: StrictStr
    email: Optional[StrictStr] = None
    first_name: Optional[StrictStr] = None


class IDatabaseMember(BaseModel):
    id: StrictStr
    user: IUser
    created_at: datetime.datetime
    updated_at: datetime.datetime


class IDatabaseMembers(BaseModel):
    database_members: List[IDatabaseMember] = []


class GetDatabaseMembersResponsePayload(APIBaseResponse):
    data: Optional[IDatabaseMembers] = None


class DeleteDatabaseMemberRequestPayload(BaseModel):
    database_member_id: StrictStr


class AddDatabaseMemberPermissionsRequestPayload(BaseModel):
    database_member_id: StrictStr
    database_member_permissions: List[StrictStr]


class DeleteDatabaseMemberPermissionsRequestPayload(BaseModel):
    database_member_id: StrictStr
    database_member_permission_id: StrictStr


class IUserPermission(BaseModel):
    id: StrictStr
    name: StrictStr
    type: Literal["db_member", "client_owner", "process_member"]
    created_at: datetime.datetime
    updated_at: datetime.datetime


class IUserPermissions(BaseModel):
    user_permissions: List[IUserPermission] = []


class GetDatabaseMemberPermissionsResponsePayload(APIBaseResponse):
    data: IUserPermissions


class GetDatabaseMemberPermissionsRequestPayload(BaseModel):
    database_member_id: StrictStr

